@@ -37,8 +37,7 @@ class Setting:
             db.execute(cmd)
             db.commit()
         elif add_new:
-            self.add_setting(text_id=key,
-                             value=value)
+            self.add_setting(text_id=key, value=value)
 
     def __contains__(self, item) -> bool:
         db = sqlite3.connect(self.database_name)
@@ -46,9 +45,10 @@ class Setting:
 
     def add_setting(self,
                     text_id: str,
+                    value: Optional,
                     readable_name: Optional[str] = "",
                     description: Optional[str] = "",
-                    value: Optional = None):
+                    ):
         db = sqlite3.connect(self.database_name)
         if text_id not in self:
             cols = [x.split()[0] for x in self.columns]
@@ -61,6 +61,7 @@ class Setting:
             cmd = f"INSERT INTO {self.table_name}({c}) VALUES({v})"
             db.execute(cmd)
             db.commit()
+            self[text_id] = value
 
     def update_setting(self,
                        text_id: str,
@@ -110,6 +111,8 @@ class Setting:
             values = [json.loads(x) for x in raw]
         except json.decoder.JSONDecodeError:
             values = [str(x) for x in raw]
+        except TypeError:
+            values = raw
         assert len(values) <= 1, f"There are more than one values stored for setting '{text_id}'"
         return values
 
